searchData={"items":[{"type":"module","title":"ReqVCR","doc":"A module to record and replay HTTP requests and responses.\n\nThe tape files are stored in the ` /vcr_tapes` directory.\nOnce a tape is recorded, it will be replayed for subsequent requests.\n\nEach tape file is a JSON file containing the request and response data. The filename\nis generated from the request method, URL, and a checksum of the URL + query parameters.\n\nHeaders are also sanitized to remove sensitive information before being stored in the tape.\nThe header keys sanitized are `[\"authorization\"]` at the moment.\n\nThe `ReqVCR.attach/2` function can be used to attach the VCR to a request and response pipeline.","ref":"ReqVCR.html"},{"type":"module","title":"Examples - ReqVCR","doc":"iex> [url: \"https://example.com\"] |> Req.new() |> ReqVCR.attach()\n\n    iex> [url: \"https://example.com\", allow_overwrite: true] |> Req.new() |> ReqVCR.attach()\n\n    iex> [url: \"https://example.com\", ignore_status: [\"404\"]] |> Req.new() |> ReqVCR.attach()","ref":"ReqVCR.html#module-examples"},{"type":"function","title":"ReqVCR.attach/2","doc":"Attaches the VCR Recorder to a request and response pipeline.","ref":"ReqVCR.html#attach/2"},{"type":"module","title":"ReqVCR.Config","doc":"Configuration module for ReqVCR.","ref":"ReqVCR.Config.html"},{"type":"function","title":"ReqVCR.Config.build/2","doc":"Build the configuration for ReqVCR.","ref":"ReqVCR.Config.html#build/2"},{"type":"function","title":"Example - ReqVCR.Config.build/2","doc":"iex> Config.build()\n    %{ignore: %{status: [401, 404, 429, 500, 502, 503]}, mode: :standby, tape_library: \"priv/vcr_tapes\", redact: %{body_params: false, request_headers: [\"authorization\"], response_headers: false, url_params: false}, tape_name: nil, mocks: %{allow_missing_tape: false}}","ref":"ReqVCR.Config.html#build/2-example"},{"type":"function","title":"ReqVCR.Config.get/1","doc":"","ref":"ReqVCR.Config.html#get/1"},{"type":"function","title":"ReqVCR.Config.get/2","doc":"","ref":"ReqVCR.Config.html#get/2"},{"type":"function","title":"ReqVCR.Config.merge_configs/2","doc":"Deep merge two config maps.\n\n  - if both values are maps, merge them recursively\n  - if any value is not a map, use the value from the override or the default","ref":"ReqVCR.Config.html#merge_configs/2"},{"type":"function","title":"Example - ReqVCR.Config.merge_configs/2","doc":"iex> merge_configs(%{a: 1, b: %{c: 2}}, %{b: %{d: 3}})\n    %{a: 1, b: %{c: 2, d: 3}}\n\n    iex> merge_configs(%{a: 1, b: %{c: 2}}, %{b: %{c: 1, d: 3}, e: 4})\n    %{a: 1, b: %{c: 2, d: 3}, e: 4}","ref":"ReqVCR.Config.html#merge_configs/2-example"},{"type":"function","title":"ReqVCR.Config.mock?/1","doc":"Check if a request is mocked.","ref":"ReqVCR.Config.html#mock?/1"},{"type":"function","title":"Example - ReqVCR.Config.mock?/1","doc":"iex> [plug: fn _ -> :ok end] |> Req.new() |> mock?()\n    false\n\n    iex> [plug: fn _, _ -> :ok end] |> Req.new() |> mock?()\n    false\n\n    iex> [plug: {Req.Test, fn _ -> :ok end}] |> Req.new() |> mock?()\n    false\n\n    iex> [plug: {Req.Test, fn _, _ -> :ok end}] |> Req.new() |> mock?()\n    false\n\n    iex> [plug: {Req.Test, HTTPClientMock}] |> Req.new() |> mock?()\n    true","ref":"ReqVCR.Config.html#mock?/1-example"},{"type":"function","title":"ReqVCR.Config.overwrite?/1","doc":"","ref":"ReqVCR.Config.html#overwrite?/1"},{"type":"module","title":"ReqVCR.Recorder","doc":"A module to record and replay HTTP requests and responses.\n\nThe tape files are stored in the ` /vcr_tapes` directory.\nOnce a tape is recorded, it will be replayed for subsequent requests.\n\nEach tape file is a JSON file containing the request and response data. The filename\nis generated from the request method, URL, and a checksum of the URL + query parameters.\n\nHeaders are also sanitized to remove sensitive information before being stored in the tape.\nThe header keys sanitized are `[\"authorization\"]` at the moment.","ref":"ReqVCR.Recorder.html"},{"type":"module","title":"Examples - ReqVCR.Recorder","doc":"iex> [url: \"https://example.com\"] |> Req.new() |> ReqVCR.Recorder.attach()\n\n    iex> [url: \"https://example.com\", allow_overwrite: true] |> Req.new() |> ReqVCR.Recorder.attach()\n\n    iex> [url: \"https://example.com\", ignore_status: [\"404\"]] |> Req.new() |> ReqVCR.Recorder.attach()","ref":"ReqVCR.Recorder.html#module-examples"},{"type":"module","title":"Options - ReqVCR.Recorder","doc":"* `:allow_overwrite` - allow overwriting existing tapes and thus bypasses replays (default: `false`)\n* `:ignore_status` - a list of status codes to ignore when recording tapes (default: `401, 404, 500, 502, 503`)\n* `:skip_recording` - skip recording the response to a tape (default: `false`)\n* `:tape_name` - a custom name for the tape file (defaults to the generated filename)","ref":"ReqVCR.Recorder.html#module-options"},{"type":"function","title":"ReqVCR.Recorder.record_tape/1","doc":"","ref":"ReqVCR.Recorder.html#record_tape/1"},{"type":"function","title":"ReqVCR.Recorder.replay_tape/1","doc":"","ref":"ReqVCR.Recorder.html#replay_tape/1"},{"type":"module","title":"ReqVCR.Redactor","doc":"A module for redacting sensitive information from requests and responses.","ref":"ReqVCR.Redactor.html"},{"type":"function","title":"ReqVCR.Redactor.redact_body/2","doc":"","ref":"ReqVCR.Redactor.html#redact_body/2"},{"type":"function","title":"ReqVCR.Redactor.redact_headers/2","doc":"","ref":"ReqVCR.Redactor.html#redact_headers/2"},{"type":"function","title":"ReqVCR.Redactor.redact_url/2","doc":"Redacts sensitive information from the given data based on the provided filters.","ref":"ReqVCR.Redactor.html#redact_url/2"},{"type":"function","title":"Parameters - ReqVCR.Redactor.redact_url/2","doc":"* `data` - the data to redact (can be a map or a URI struct)\n  * `filters` - a list of keys to redact","ref":"ReqVCR.Redactor.html#redact_url/2-parameters"},{"type":"function","title":"Returns - ReqVCR.Redactor.redact_url/2","doc":"* the redacted data","ref":"ReqVCR.Redactor.html#redact_url/2-returns"},{"type":"module","title":"ReqVCR.Tape","doc":"A struct representing a tape.","ref":"ReqVCR.Tape.html"},{"type":"function","title":"ReqVCR.Tape.new/2","doc":"Builds a new tape from a request and an optional response.","ref":"ReqVCR.Tape.html#new/2"},{"type":"function","title":"Parameters - ReqVCR.Tape.new/2","doc":"* `request` - the original request\n  * `response` - the optional response (default: `nil`)","ref":"ReqVCR.Tape.html#new/2-parameters"},{"type":"function","title":"Returns - ReqVCR.Tape.new/2","doc":"* a `%Tape{}` struct representing the tape","ref":"ReqVCR.Tape.html#new/2-returns"},{"type":"function","title":"ReqVCR.Tape.record/1","doc":"Records a tape to a file.","ref":"ReqVCR.Tape.html#record/1"},{"type":"function","title":"Parameters - ReqVCR.Tape.record/1","doc":"* `tape` - the tape to record","ref":"ReqVCR.Tape.html#record/1-parameters"},{"type":"function","title":"Returns - ReqVCR.Tape.record/1","doc":"* `:ok` if the tape was successfully recorded\n  * `{:error, reason}` if there was an error recording the tape","ref":"ReqVCR.Tape.html#record/1-returns"},{"type":"type","title":"ReqVCR.Tape.replay/0","doc":"","ref":"ReqVCR.Tape.html#t:replay/0"},{"type":"function","title":"ReqVCR.Tape.replay/1","doc":"Replays a tape from a file.","ref":"ReqVCR.Tape.html#replay/1"},{"type":"function","title":"Parameters - ReqVCR.Tape.replay/1","doc":"* `tape` - the tape to replay","ref":"ReqVCR.Tape.html#replay/1-parameters"},{"type":"function","title":"Returns - ReqVCR.Tape.replay/1","doc":"* `{:ok, map()}` if the tape was successfully replayed\n  * `{:error, reason}` if there was an error replaying the tape","ref":"ReqVCR.Tape.html#replay/1-returns"},{"type":"type","title":"ReqVCR.Tape.t/0","doc":"","ref":"ReqVCR.Tape.html#t:t/0"},{"type":"module","title":"ReqVCR.Test","doc":"ReqVCR testing conveniences.\n\nThis module provides utilities to mock HTTP requests and responses using VCR tapes. It integrates with `Req.Test` to allow recording and replaying HTTP interactions.","ref":"ReqVCR.Test.html"},{"type":"module","title":"Usage - ReqVCR.Test","doc":"","ref":"ReqVCR.Test.html#module-usage"},{"type":"module","title":"Recording a VCR Tape - ReqVCR.Test","doc":"To record a VCR tape, you need to set the `:vcr` option with `:mode` set to `:record` and specify a `:tape_name`. This will record the HTTP interaction to the specified tape.\n\n```elixir\nopts = [vcr: [mode: :record, tape_name: \"example-tape.json\"]]\n{:ok, response} = vcr_request(\"https://example.com\", opts)\nassert %{action: :record, recorded: true} = Req.Response.get_private(response, :vcr)\n```","ref":"ReqVCR.Test.html#module-recording-a-vcr-tape"},{"type":"module","title":"Replaying a VCR Tape - ReqVCR.Test","doc":"To replay a VCR tape, you can use the `plug_vcr_replay/1` function. This function sets up a mock that will respond with the recorded interaction from the specified tape.\n\n```elixir\nopts = [\n  plug: plug_vcr_replay(\"example-tape.json\"),\n  vcr: [mode: :record, tape_name: \"example-tape.json\"]\n]\n{:ok, response} = vcr_request(\"https://example.com\", opts)\nassert %{action: :replay, source: :mock} = Req.Response.get_private(response, :vcr)\n```","ref":"ReqVCR.Test.html#module-replaying-a-vcr-tape"},{"type":"module","title":"Replaying Multiple VCR Tapes - ReqVCR.Test","doc":"You can also replay multiple VCR tapes sequentially by passing a list of tape names to `plug_vcr_replay/1`.\n\n```elixir\nvcr_configs = [\n  {\"https://example.com/endpoint1\", \"tape1.json\"},\n  {\"https://example.com/endpoint2\", \"tape2.json\"}\n]\n\nplug_vcr_replays =\n  vcr_configs\n  |> Enum.map(&elem(&1, 1))\n  |> plug_vcr_replay()\n\nfor {endpoint, tape_name} <- vcr_configs do\n  opts = [\n    plug: plug_vcr_replays,\n    vcr: [mode: :record, tape_name: tape_name]\n  ]\n  {:ok, response} = vcr_request(endpoint, opts)\n  assert %{action: :replay, source: :mock} == Req.Response.get_private(response, :vcr)\nend\n```","ref":"ReqVCR.Test.html#module-replaying-multiple-vcr-tapes"},{"type":"function","title":"ReqVCR.Test.expect_replay/2","doc":"Sets up an expectation to replay a VCR tape.\n\nThis function sets up a mock that will respond with the recorded interaction from the specified tape(s). It uses `Req.Test.expect/2` to create the expectation.","ref":"ReqVCR.Test.html#expect_replay/2"},{"type":"function","title":"Options - ReqVCR.Test.expect_replay/2","doc":"- `tape_names`: The name of the VCR tape or a list of VCR tape names to replay.\n  - `opts`: Optional keyword list of options.","ref":"ReqVCR.Test.html#expect_replay/2-options"},{"type":"function","title":"ReqVCR.Test.stub_replay/2","doc":"Sets up a stub to replay a VCR tape.\n\nThis function sets up a mock that will respond with the recorded interaction\nfrom the specified tape(s). It uses `Req.Test.stub/2` to create the stub.","ref":"ReqVCR.Test.html#stub_replay/2"},{"type":"function","title":"Options - ReqVCR.Test.stub_replay/2","doc":"- `tape_names`: The name of the VCR tape or a list of VCR tape names to replay.\n  - `opts`: Optional keyword list of options.","ref":"ReqVCR.Test.html#stub_replay/2-options"},{"type":"function","title":"ReqVCR.Test.vcr_request/2","doc":"This function makes a request with VCR attached. It takes a URL and an optional list of VCR options.","ref":"ReqVCR.Test.html#vcr_request/2"},{"type":"function","title":"ReqVCR.Test.vcr_response/1","doc":"This function gets the VCR config from a Req response.","ref":"ReqVCR.Test.html#vcr_response/1"},{"type":"function","title":"ReqVCR.Test.vcr_tape_exists?/1","doc":"Check if a VCR tape exists.","ref":"ReqVCR.Test.html#vcr_tape_exists?/1"},{"type":"function","title":"Example - ReqVCR.Test.vcr_tape_exists?/1","doc":"iex> vcr_tape_exists?(\"tape.json\")\n  true\n\n  iex> vcr_tape_exists?(\"missing-tape.json\")\n  false","ref":"ReqVCR.Test.html#vcr_tape_exists?/1-example"},{"type":"macro","title":"ReqVCR.Test.with_vcr_tape/2","doc":"","ref":"ReqVCR.Test.html#with_vcr_tape/2"},{"type":"macro","title":"ReqVCR.Test.with_vcr_tape/3","doc":"Convenience macro to run a function with a VCR tape.\n\nThis macro is useful for running a block of code with a VCR tape.\nIt takes a `tape_name` and an optional list of VCR options.","ref":"ReqVCR.Test.html#with_vcr_tape/3"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.0"}}